% method of class @signal
% function [meansig,stdsig]=average(sig,[t_start],[t_stop])
% calculates the average value of the signal
%
%   INPUT VALUES:
%       sig:  original @signal
%       t_start: start time in seconds [0]
%       t_stop: stop time in seconds [getlength(sig)]
%    
%   RETURN VALUE:
%       meansig: mean value of the signal
%       stdsug: standart deviation
%
% (c) 2003-2008, University of Cambridge, Medical Research Council 
% Maintained by Tom Walters (tcw24@cam.ac.uk), written by Stefan Bleeck (stefan@bleeck.de)
% http://www.pdn.cam.ac.uk/cnbh/aim2006
% $Date: 2008-06-10 18:00:16 +0100 (Tue, 10 Jun 2008) $
% $Revision: 585 $

function [meana,stda]=average(sig,t_start,t_stop)


if nargin < 2
    t_start=getminimumtime(sig);
end
if nargin < 3
    t_stop=t_start+getlength(sig);
end

intstart=time2bin(sig,t_start);
intstop=time2bin(sig,t_stop);

if intstart==0
    intstart=1;
end

if intstart>intstop
    error('signal::average: stoptime < starttime');
end


s=sig.werte(intstart:intstop);
if max(size(s))>1
    meana=mean(s);
    stda=std(s);
else
    meana=s;
    stda=0;
end    
